import { useState, useEffect } from "react";
import Box from "@mui/material/Box";
import {
  FileBrowser,
  FileContextMenu,
  FileList,
  FileNavbar,
  FileToolbar,
  setChonkyDefaults,
} from "chonky";
import { ChonkyIconFA } from "chonky-icon-fontawesome";

import { getServerFiles } from "@mcl/queries";

export default function MineclusterFiles(props) {
  setChonkyDefaults({ iconComponent: ChonkyIconFA });
  const { server: serverName } = props;
  const [dirStack, setDirStack] = useState(["."]);
  const [files, setFiles] = useState([]);
  useEffect(() => {
    getServerFiles(serverName, dirStack.join("/")).then((f) =>
      setFiles(f ?? []),
    );
  }, [dirStack]);

  const getFolderChain = () => {
    if (dirStack.length === 1) return [{ id: "home", name: "/", isDir: true }];
    return dirStack.map((d, i) => ({ id: `${d}-${i}`, name: d, isDir: true }));
  };

  function fileClick(chonkyEvent) {
    const { id: clickEvent, payload } = chonkyEvent;
    console.log(chonkyEvent);
    if (clickEvent === `open_parent_folder`)
      return setDirStack(dirStack.slice(0, -1));
    if (clickEvent !== `open_files`) return console.log(clickEvent);
    const { targetFile: file } = payload;
    if (!file || !file.isDir) return;
    setDirStack([...dirStack, file.name]);
  }
  return (
    <Box className="minecluster-files" sx={{ height: "calc(100vh - 6rem)" }}>
      <FileBrowser
        files={files}
        folderChain={getFolderChain()}
        onFileAction={fileClick}
      >
        <FileNavbar />
        <FileToolbar />
        <FileList />
        <FileContextMenu />
      </FileBrowser>
    </Box>
  );
}
